<?php

namespace Litecms\MasterDifficulty\Http\Controllers;

use Exception;
use Litepie\Http\Controllers\ResourceController as BaseController;
use Litepie\Repository\Filter\RequestFilter;
use Litecms\MasterDifficulty\Forms\MasterDifficulty as MasterDifficultyForm;
use Litecms\MasterDifficulty\Http\Requests\MasterDifficultyRequest;
use Litecms\MasterDifficulty\Interfaces\MasterDifficultyRepositoryInterface;
use Litecms\MasterDifficulty\Repositories\Eloquent\Filters\MasterDifficultyResourceFilter;
use Litecms\MasterDifficulty\Repositories\Eloquent\Presenters\MasterDifficultyListPresenter;

/**
 * Resource controller class for master_difficulty.
 */
class MasterDifficultyResourceController extends BaseController
{

    /**
     * Initialize master_difficulty resource controller.
     *
     *
     * @return null
     */
    public function __construct(MasterDifficultyRepositoryInterface $master_difficulty)
    {
        parent::__construct();
        $this->form = MasterDifficultyForm::setAttributes()->toArray();
        $this->modules = $this->modules(config('litecms.master_difficulty.modules'), 'master_difficulty', guard_url('master_difficulty'));
        $this->repository = $master_difficulty;
    }

    /**
     * Display a list of master_difficulty.
     *
     * @return Response
     */
    public function index(MasterDifficultyRequest $request)
    {

        $pageLimit = $request->input('pageLimit', config('database.pagination.limit'));
        $data = $this->repository
            ->pushFilter(RequestFilter::class)
            ->pushFilter(MasterDifficultyResourceFilter::class)
            ->setPresenter(MasterDifficultyListPresenter::class)
            ->simplePaginate($pageLimit)
            // ->withQueryString()
            ->toArray();

        extract($data);
        $form = $this->form;
        $modules = $this->modules;

        return $this->response->setMetaTitle(trans('master_difficulty::master_difficulty.names'))
            ->view('master_difficulty::master_difficulty.index')
            ->data(compact('data', 'meta', 'links', 'modules', 'form'))
            ->output();
    }

    /**
     * Display master_difficulty.
     *
     * @param Request $request
     * @param Model   $master_difficulty
     *
     * @return Response
     */
    public function show(MasterDifficultyRequest $request, MasterDifficultyRepositoryInterface $repository)
    {
        $form = $this->form;
        $modules = $this->modules;
        $data = $repository->toArray();
        return $this->response
            ->setMetaTitle(trans('app.view') . ' ' . trans('master_difficulty::master_difficulty.name'))
            ->data(compact('data', 'form', 'modules', 'form'))
            ->view('master_difficulty::master_difficulty.show')
            ->output();
    }

    /**
     * Show the form for creating a new master_difficulty.
     *
     * @param Request $request
     *x
     * @return Response
     */
    public function create(MasterDifficultyRequest $request, MasterDifficultyRepositoryInterface $repository)
    {
        $form = $this->form;
        $modules = $this->modules;
        $data = $repository->toArray();
        return $this->response->setMetaTitle(trans('app.new') . ' ' . trans('master_difficulty::master_difficulty.name'))
            ->view('master_difficulty::master_difficulty.create')
            ->data(compact('data', 'form', 'modules'))
            ->output();
    }

    /**
     * Create new master_difficulty.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(MasterDifficultyRequest $request, MasterDifficultyRepositoryInterface $repository)
    {
        try {
            $attributes = $request->all();
            $attributes['user_id'] = user_id();
            $attributes['user_type'] = user_type();
            $repository->create($attributes);
            $data = $repository->toArray();

            return $this->response->message(trans('messages.success.created', ['Module' => trans('master_difficulty::master_difficulty.name')]))
                ->code(204)
                ->data(compact('data'))
                ->status('success')
                ->url(guard_url('master_difficulty/master_difficulty/' . $data['id']))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('/master_difficulty/master_difficulty'))
                ->redirect();
        }

    }

    /**
     * Show master_difficulty for editing.
     *
     * @param Request $request
     * @param Model   $master_difficulty
     *
     * @return Response
     */
    public function edit(MasterDifficultyRequest $request, MasterDifficultyRepositoryInterface $repository)
    {
        $form = $this->form;
        $modules = $this->modules;
        $data = $repository->toArray();

        return $this->response->setMetaTitle(trans('app.edit') . ' ' . trans('master_difficulty::master_difficulty.name'))
            ->view('master_difficulty::master_difficulty.edit')
            ->data(compact('data', 'form', 'modules'))
            ->output();
    }

    /**
     * Update the master_difficulty.
     *
     * @param Request $request
     * @param Model   $master_difficulty
     *
     * @return Response
     */
    public function update(MasterDifficultyRequest $request, MasterDifficultyRepositoryInterface $repository)
    {
        try {
            $attributes = $request->all();
            $repository->update($attributes);
            $data = $repository->toArray();

            return $this->response->message(trans('messages.success.updated', ['Module' => trans('master_difficulty::master_difficulty.name')]))
                ->code(204)
                ->status('success')
                ->data(compact('data'))
                ->url(guard_url('master_difficulty/master_difficulty/' . $data['id']))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('master_difficulty/master_difficulty/' .  $repository->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove the master_difficulty.
     *
     * @param Model   $master_difficulty
     *
     * @return Response
     */
    public function destroy(MasterDifficultyRequest $request, MasterDifficultyRepositoryInterface $repository)
    {
        try {
            $repository->delete();
            $data = $repository->toArray();

            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('master_difficulty::master_difficulty.name')]))
                ->code(202)
                ->status('success')
                ->data(compact('data'))
                ->url(guard_url('master_difficulty/master_difficulty/0'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('master_difficulty/master_difficulty/' .  $repository->getRouteKey()))
                ->redirect();
        }

    }
}
